@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright (c) 2011, 2012, 2013 Red Hat, Inc.
  *
  * Gnome Documents is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -248,8 +248,8 @@ const DocCommon = new Lang.Class({
         this.populateFromCursor(cursor);
 
         this._refreshIconId =
-            Application.application.connect('action-state-changed::view-as',
-                                            Lang.bind(this, this.refreshIcon));
+            Application.settings.connect('changed::view-as',
+                                         Lang.bind(this, this.refreshIcon));
         this._filterId =
             Application.searchCategoryManager.connect('active-changed',
                                                       Lang.bind(this, this.refreshIcon));
@@ -355,18 +355,6 @@ const DocCommon = new Lang.Class({
         }
     },
 
-    canEdit: function() {
-        log('Error: DocCommon implementations must override canEdit');
-    },
-
-    canShare: function() {
-        log('Error: DocCommon implementations must override canShare');
-    },
-
-    canTrash: function() {
-        log('Error: DocCommon implementations must override canTrash');
-    },
-
     createThumbnail: function(callback) {
         log('Error: DocCommon implementations must override createThumbnail');
     },
@@ -460,20 +448,14 @@ const DocCommon = new Lang.Class({
                                     this.thumbnailed = true;
                                     this._setOrigPixbuf(pixbuf);
                                 } catch (e) {
-                                    log('Unable to create pixbuf from ' + thumbFile.get_uri() + ': ' + e.toString());
                                     this._failedThumbnailing = true;
-                                    this._thumbPath = null;
-                                    thumbFile.delete_async(GLib.PRIORITY_DEFAULT, null, null);
                                 }
 
                                 // close the underlying stream immediately
                                 stream.close_async(0, null, null);
                             }));
                 } catch (e) {
-                    log('Unable to read file at ' + thumbFile.get_uri() + ': ' + e.toString());
                     this._failedThumbnailing = true;
-                    this._thumbPath = null;
-                    thumbFile.delete_async(GLib.PRIORITY_DEFAULT, null, null);
                 }
             }));
     },
@@ -561,7 +543,7 @@ const DocCommon = new Lang.Class({
             this._collectionIconWatcher = null;
         }
 
-        Application.application.disconnect(this._refreshIconId);
+        Application.settings.disconnect(this._refreshIconId);
         Application.searchCategoryManager.disconnect(this._filterId);
     },
 
@@ -671,14 +653,6 @@ const LocalDocument = new Lang.Class({
             }));
     },
 
-    canEdit: function() {
-        return false;
-    },
-
-    canShare: function() {
-        return false;
-    },
-
     canTrash: function() {
         return this.collection;
     },
@@ -738,7 +712,7 @@ const GoogleDocument = new Lang.Class({
             function(entry, service, exception) {
                 if (exception) {
                     // try loading from the most recent cache, if any
-                    GdPrivate.pdf_loader_load_uri_async(this.identifier, passwd, cancellable, Lang.bind(this,
+                    GdPrivate.pdf_loader_load_uri_async(this.identifier, cancellable, Lang.bind(this,
                         function(source, res) {
                             try {
                                 let docModel = GdPrivate.pdf_loader_load_uri_finish(res);
@@ -787,7 +761,7 @@ const GoogleDocument = new Lang.Class({
                 let checksum = new GLib.Checksum(GLib.ChecksumType.MD5);
                 checksum.update(this.uri, -1);
                 let dirPath = GLib.build_filenamev([GLib.get_user_cache_dir(), "thumbnails", "normal"]);
-                GLib.mkdir_with_parents(dirPath, 0700);
+                GLib.mkdir_with_parents(dirPath, 448);
                 let basename = checksum.get_string() + '.png';
                 let path = GLib.build_filenamev([dirPath, basename])
 
@@ -842,14 +816,6 @@ const GoogleDocument = new Lang.Class({
         this.parent(cursor);
     },
 
-    canEdit: function() {
-        return true;
-    },
-
-    canShare: function() {
-        return true;
-    },
-
     canTrash: function() {
         return false;
     }
@@ -906,14 +872,6 @@ const OwncloudDocument = new Lang.Class({
             }));
     },
 
-    canEdit: function() {
-        return false;
-    },
-
-    canShare: function() {
-        return false;
-    },
-
     canTrash: function() {
         return false;
     }
@@ -964,7 +922,7 @@ const SkydriveDocument = new Lang.Class({
             function(entry, service, exception) {
                 if (exception) {
                     // try loading from the most recent cache, if any
-                    GdPrivate.pdf_loader_load_uri_async(this.identifier, passwd, cancellable, Lang.bind(this,
+                    GdPrivate.pdf_loader_load_uri_async(this.identifier, cancellable, Lang.bind(this,
                         function(source, res) {
                             try {
                                 let docModel = GdPrivate.pdf_loader_load_uri_finish(res);
@@ -1006,14 +964,6 @@ const SkydriveDocument = new Lang.Class({
         this.typeDescription = description;
     },
 
-    canEdit: function() {
-        return false;
-    },
-
-    canShare: function() {
-        return false;
-    },
-
     canTrash: function() {
         return false;
     }
