@@ -34,7 +34,6 @@ const WindowMode = imports.windowMode;
 const Documents = imports.documents;
 
 const EvView = imports.gi.EvinceView;
-const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
@@ -163,13 +162,13 @@ const EmptyResultsBox = new Lang.Class({
 
     _addSystemSettingsLabel: function() {
         let detailsStr =
-            // Translators: %s here is "System Settings", which is in a separate string
-            // due to markup, and should be translated only in the context of this sentence
+            // Translators: %s here is "Settings", which is in a separate string due to
+            // markup, and should be translated only in the context of this sentence
             _("You can add your online accounts in %s").format(
             " <a href=\"system-settings\">" +
             // Translators: this should be translated in the context of the
-            // "You can add your online accounts in System Settings" sentence above
-            _("System Settings") +
+            // "You can add your online accounts in Settings" sentence above
+            _("Settings") +
             "</a>");
         let details = new Gtk.Label({ label: detailsStr,
                                       use_markup: true,
@@ -281,14 +280,6 @@ const Embed = new Lang.Class({
             this._onWindowModeChanged(Application.modeController, windowMode, WindowMode.WindowMode.NONE);
     },
 
-    _onActivateResult: function() {
-        let iter = this._view.model.model.get_iter_first()[1];
-        if (iter) {
-            let id = this._view.model.model.get_value(iter, Gd.MainColumns.ID);
-            Application.documentManager.setActiveItem(Application.documentManager.getItemById(id))
-        };
-    },
-
     _onQueryStatusChanged: function() {
         let windowMode = Application.modeController.getWindowMode();
         if (windowMode != WindowMode.WindowMode.OVERVIEW)
@@ -363,8 +354,6 @@ const Embed = new Lang.Class({
             throw(new Error('Not handled'));
             break;
         }
-        this._toolbar.searchbar.connect('activate-result',
-                                        Lang.bind(this, this._onActivateResult));
     },
 
     _onActiveItemChanged: function(manager, doc) {
@@ -426,7 +415,7 @@ const Embed = new Lang.Class({
         dialog.widget.connect('response', Lang.bind(this,
             function(widget, response) {
                 dialog.widget.destroy();
-                if (response == Gtk.ResponseType.CANCEL || response == Gtk.ResponseType.DELETE_EVENT)
+                if (response == Gtk.ResponseType.CANCEL)
                     Application.documentManager.setActiveItem(null);
             }));
     },
