@@ -49,9 +49,9 @@ const MainToolbar = new Lang.Class({
         this.widget.add(this.toolbar);
         this.toolbar.show();
 
-        this.searchbar = this.createSearchbar();
-        if (this.searchbar)
-            this.widget.add(this.searchbar.widget);
+        this._searchbar = this.createSearchbar();
+        if (this._searchbar)
+            this.widget.add(this._searchbar.widget);
 
         Application.documentManager.connect('load-started', Lang.bind(this,
             function() {
@@ -70,7 +70,7 @@ const MainToolbar = new Lang.Class({
         if (!this._handleEvent)
             return false;
 
-        let res = this.searchbar.handleEvent(event);
+        let res = this._searchbar.handleEvent(event);
         return res;
     },
 
@@ -103,6 +103,9 @@ const OverviewToolbar = new Lang.Class({
         this._collectionId = 0;
         this._selectionChangedId = 0;
         this._selectionMenu = null;
+        this._viewGridButton = null;
+        this._viewListButton = null;
+        this._viewSettingsId = 0;
 
         this.parent();
 
@@ -150,6 +153,36 @@ const OverviewToolbar = new Lang.Class({
             }));
     },
 
+    _addViewAsButtons: function() {
+        let viewAsBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
+                                      spacing: 0 });
+        viewAsBox.get_style_context().add_class('linked');
+        this.toolbar.pack_end(viewAsBox);
+
+        this._viewListButton = new Gd.HeaderSimpleButton({ symbolic_icon_name: 'view-list-symbolic',
+                                                           label: _("View items as a list"),
+                                                           no_show_all: true,
+                                                           action_name: 'app.view-as',
+                                                           action_target: GLib.Variant.new('s', 'list') });
+        viewAsBox.add(this._viewListButton);
+        this._viewGridButton = new Gd.HeaderSimpleButton({ symbolic_icon_name: 'view-grid-symbolic',
+                                                           label: _("View items as a grid of icons"),
+                                                           no_show_all: true,
+                                                           action_name: 'app.view-as',
+                                                           action_target: GLib.Variant.new('s', 'icon') });
+        viewAsBox.add(this._viewGridButton);
+
+        this._viewSettingsId = Application.settings.connect('changed::view-as',
+            Lang.bind(this, this._updateViewAsButtons));
+        this._updateViewAsButtons();
+    },
+
+    _updateViewAsButtons: function() {
+        let viewType = Application.settings.get_enum('view-as');
+        this._viewGridButton.visible = (viewType != Gd.MainViewType.ICON);
+        this._viewListButton.visible = (viewType != Gd.MainViewType.LIST);
+    },
+
     _setToolbarTitle: function() {
         let selectionMode = Application.selectionController.getSelectionMode();
         let activeCollection = Application.collectionManager.getActiveItem();
@@ -196,8 +229,6 @@ const OverviewToolbar = new Lang.Class({
     _populateForSelectionMode: function() {
         this.toolbar.get_style_context().add_class('selection-mode');
 
-        this.addSearchButton();
-
         let builder = new Gtk.Builder();
         builder.add_from_resource('/org/gnome/documents/selection-menu.ui');
         let selectionMenu = builder.get_object('selection-menu');
@@ -217,6 +248,8 @@ const OverviewToolbar = new Lang.Class({
         this._selectionChangedId =
             Application.selectionController.connect('selection-changed',
                                                Lang.bind(this, this._setToolbarTitle));
+
+        this.addSearchButton();
     },
 
     _checkCollectionBackButton: function() {
@@ -244,7 +277,6 @@ const OverviewToolbar = new Lang.Class({
     _populateForOverview: function() {
         this.toolbar.set_show_close_button(true);
         this._checkCollectionBackButton();
-        this.addSearchButton();
 
         let selectionButton = new Gd.HeaderSimpleButton({ symbolic_icon_name: 'object-select-symbolic',
                                                           label: _("Select Items") });
@@ -254,6 +286,9 @@ const OverviewToolbar = new Lang.Class({
                 Application.selectionController.setSelectionMode(true);
             }));
 
+        this._addViewAsButtons();
+        this.addSearchButton();
+
         // connect to active collection changes while in this mode
         this._collectionId =
             Application.collectionManager.connect('active-changed',
@@ -263,6 +298,8 @@ const OverviewToolbar = new Lang.Class({
     _clearStateData: function() {
         this._collBackButton = null;
         this._selectionMenu = null;
+        this._viewGridButton = null;
+        this._viewListButton = null;
         this.toolbar.set_custom_title(null);
 
         if (this._collectionId != 0) {
@@ -274,6 +311,11 @@ const OverviewToolbar = new Lang.Class({
             Application.selectionController.disconnect(this._selectionChangedId);
             this._selectionChangedId = 0;
         }
+
+        if (this._viewSettingsId != 0) {
+            Application.settings.disconnect(this._viewSettingsId);
+            this._viewSettingsId = 0;
+        }
     },
 
     _clearToolbar: function() {
